# CSL/Clio

Ce dépôt contient les fichiers source du projet _CSL/Clio_. Les fichiers
PDF du manuel, les feuilles de style, les filtres et les macros sont
hébergés sur [Zenodo](https://zenodo.org/communities/csl-clio/).
Vous pouvez également les obtenir directement sur ce dépôt et compiler
le manuel.

## Présentation du projet

_CSL/Clio_ vise à fournir des outils permettant de compenser les limites
du [langage de mise en forme de citations CSL](https://citationstyles.org), 
sur lequel repose notamment le logiciel [Zotero](https://www.zotero.org).
Par le biais de détournement et de spécialisation de variables présentes
dans les spécifications CSL, il permet notamment de faire face à des
exigences variées pour la citation de sources primaires. 

Le projet fournit des styles CSL, des macros pour LibreOffice et des filtres
pour [Pandoc](https://pandoc.org). Certaines de ces ressources peuvent
s'avérer utiles dans d'autres disciplines que l'Histoire.

## Développement

Le fichier `Utilitaires/Makefile` fait appel aux programmes suivants :

  * Pour les tests :
    * bash
    * pandoc >=2.13
    * dwdiff
    * sort
    * uniq
    * palemoon (peut être remplacé en renseignant la variable `HTML-VIEWER`)
  * Pour la documentation :
    * pandoc
    * une distribution TeX contenant LuaLaTeX et ConTeXt (dans le futur, la dépendance à LaTeX pourra être supprimée)
    
Chaque éditeur ou revue possède son propre répertoire, contenant :

  * un fichier `*.csl` ;
  * un fichier `*_CSL-Validation.html` correspondant au résultat attendu du traitement du fichier `Tests-Data/CSL-Tests.md` par Pandoc avec l'option `citeproc` et les filtres spécifiés dans les fichiers `*_filters-first.txt` et `*_filters-last.txt`.
  
Les cibles suivantes requièrent que la variable `JOURNAL` soit renseignée par la ligne de commande avec le nom d'un des répertoires :

  * `test` : compare le fichier produit par Pandoc à l'aide du fichier `*.csl` avec le fichier `*_CSL-Validation.html` ;
  * `test-compact` : même chose, mais compare les mots plutôt que les lignes entières et produit un résultat plus compact ;
  * `validation-prov` : produit via Pandoc un fichier HTML en appliquant le style CSL fourni dans le répertoire et l'ouvre dans le navigateur défini par la variable `HTML-VIEWER` ;
  * `validation-docx` : produit via Pandoc un fichier de validation provisoire au format DOCX, permettant par exemple de le faire corriger par un tiers ;
  * `install` : valide le fichier de validation provisoire ;
  * `clean`.

L'idée est de rédiger une première version de la feuille de style CSL,
générer un fichier de validation provisoire, le corriger manuellement,
l'installer, puis modifier la feuille de style jusqu'à ce que le fichier HTML
produit par Pandoc soit identique au fichier de validation ainsi obtenu.
Bien entendu, si certaines exigences de l'éditeur ne peuvent être satisfaites
ni par CSL, ni par un filtre Pandoc, le fichier de validation doit en tenir
compte.

Les cibles `docA4` et `docDiapo` produisent la documentation
particulière à la revue ou à l'éditeur visé si la variable `JOURNAL`
est spécifiée et le guide général de _CSL/Clio_ dans le cas contaire.

## Comment contribuer

Toutes les bonnes volontés sont bienvenues ! Si vous souhaitez contribuer,
vous pouvez vous référer au manuel, qui contient les informations nécessaires,
et m'écrire ou ouvrir un ticket sur ce dépôt.
